@@ -35,7 +35,7 @@ extern GtkWidget *databox;
 #define DEBUG 0
 
 int     triggered = 0;          /* whether we've triggered or not */
-void    *font;
+//void    *font;
 int     math_warning = 0;       /* TRUE if math has a problem */
 
 struct signal_stats stats;
@@ -74,7 +74,7 @@ gboolean clear_message_callback(gpointer ignored)
 void message(const char *message)
 {
     if (databox_message == NULL) {
-        GdkColor gcolor;
+        GdkRGBA gcolor;
         gcolor.red = gcolor.green = gcolor.blue = 65535;
         databox_message = gtk_databox_markers_new(1, &databox_message_X,
                                                   &databox_message_Y, &gcolor, 0,
@@ -448,7 +448,7 @@ void update_dynamic_text(void)
 
 void update_text(void)
 {
-    char string[81], widget[81];
+    char string[281], widget[81];
     int i;
     Channel *p;
     static char *plot_styles[] = {
@@ -584,7 +584,11 @@ void update_text(void)
         } else {
             gtk_frame_set_shadow_type(GTK_FRAME(LU(widget)), GTK_SHADOW_NONE);
         }
-
+	
+	sprintf(widget, "Ch%1d_toggle", i+1);
+	set_fixing_widgets (TRUE);
+	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(LU(widget)), ch[i].show);
+	set_fixing_widgets (FALSE);
     }
 
     /* below graticule */
@@ -743,8 +747,8 @@ void recompute_graticule(void)
 
 void create_graticule(void)
 {
-    GtkStyle *style;
-    GdkColor gcolor;
+    GtkStyleContext *style;
+    GdkRGBA gcolor;
 
 #if 0
     static int i, j;
@@ -768,15 +772,13 @@ void create_graticule(void)
 #endif
 
     /* Use the same color for the graticule that is used for the frame around the databox, which is
-     * its BACKGROUND color.
+     * its FOREGROUND color.
      */
-
-    style = gtk_widget_get_style(GTK_WIDGET(LU("databox_aspectframe")));
-    gcolor = style->bg[GTK_STATE_NORMAL];
+    style = gtk_widget_get_style_context (GTK_WIDGET(LU("databox_aspectframe")));
+    gtk_style_context_get_color (style, GTK_STATE_FLAG_NORMAL, &gcolor);
 
     /* the minor graticule grid - the scope display is divided into a 10x10 grid with 9x9 lines
      */
-
     graticule_minor_graph = gtk_databox_grid_new (9, 9, &gcolor, 1);
     graticule_major_graph = gtk_databox_grid_new (1, 1, &gcolor, 1);
 
@@ -919,7 +921,7 @@ void configure_databox(void)
 
     {
         gfloat X, Y;
-        GdkColor gcolor;
+        GdkRGBA gcolor;
         GtkDataboxGraph *line = gtk_databox_lines_new(1, &X, &Y, &gcolor, 1);
 
         x_offset_property_exists = (g_object_class_find_property(G_OBJECT_GET_CLASS(line), "x-offset") != NULL);
@@ -1104,8 +1106,8 @@ void draw_data(void)
     SignalLine *sl;
     short *samp;
     gchar widget[80];
-    GtkStyle *style;
-    GdkColor gcolor;
+    GtkStyleContext *style;
+    GdkRGBA gcolor;
     SignalLine *prevSL;
     double x_offset;
 
@@ -1138,10 +1140,9 @@ void draw_data(void)
         if (p->show && p->signal) {
 
             /* Figure out color to use for this channel by fetching foreground color of its label */
-
             sprintf(widget, "Ch%d_label", j+1);
-            style = gtk_widget_get_style(GTK_WIDGET(LU(widget)));
-            gcolor = style->fg[GTK_STATE_NORMAL];
+	    style = gtk_widget_get_style_context (GTK_WIDGET(LU(widget)));
+	    gtk_style_context_get_color (style, GTK_STATE_FLAG_NORMAL, &gcolor);
 
             samp = p->signal->data;
 
@@ -1438,7 +1439,6 @@ void draw_data(void)
                             g_value_set_double(&gvalue, prevSL->y_offset);
                             g_object_set_property((GObject *) prevSL->graph, "y-offset", &gvalue);
 
-                            g_value_unset(&gvalue);
                             //g_object_set_property((GObject *) prevSL->graph, "plot-style", &plotstyle);
                         } else {
                             for (i = 0; i < prevSL->next_point; i++) {
