@@ -1,5 +1,4 @@
-/*
- * @(#)$Id: file.h,v 2.0 2008/12/17 17:35:46 baccala Exp $
+/* -*- mode: C++; indent-tabs-mode: nil; fill-column: 100; c-basic-offset: 4; -*-
  *
  * Copyright (C) 1996 Tim Witham <twitham@pcocd2.intel.com>
  *
@@ -9,11 +8,8 @@
  *
  */
 
-void
-handle_opt(char opt, char *optarg);
+void handle_opt(char opt, char *optarg);
 
-void
-writefile(char *filename);
+void writefile(char *filename);
 
-void
-readfile(char *filename);
+void readfile(char *filename);
