@@ -1002,14 +1002,14 @@ void measure_data(Channel *sig, struct signal_stats *stats)
     short   val, prev;
     int     min=0, max=0, midpoint=0;
     int     first = 0, last = 0, count = 0, imax = 0;
-#ifdef CALC_RMS
+#if CALC_RMS
     int     second = 0.0;
 #endif	
     stats->min = 0;
     stats->max = 0;
     stats->time = 0;
     stats->freq = 0;
-#ifdef CALC_RMS
+#if CALC_RMS
     stats->rms = 0.0;
 #endif
 
@@ -1064,7 +1064,7 @@ void measure_data(Channel *sig, struct signal_stats *stats)
                 if(rising > 5){
                     if (!first)
                         first = i;
-#ifdef CALC_RMS
+#if CALC_RMS
                     else if (!second)
                         second = i;
 #endif
@@ -1076,17 +1076,17 @@ void measure_data(Channel *sig, struct signal_stats *stats)
             prev = val;
         }
 
-#ifdef CALC_RMS
+#if CALC_RMS
         for (i = first; i < second; i++) {
             stats->rms += (sig->signal->data[i] * sig->signal->data[i]);
         }
         if((second - first) != 0){
-        stats->rms = sqrt(stats->rms / (second - first));
+            stats->rms = sqrt(stats->rms / (second - first));
         }
         else {
-        stats->rms = -1;
+            stats->rms = -1;
         }
-#endif // CALC_RMS
+#endif
 
         stats->min = min;
         stats->max = max;
