@@ -21,25 +21,25 @@
 /* global program structures */
 Scope scope;
 
+#ifdef HAVE_LIBCOMEDI
+extern DataSrc datasrc_comedi;
+#endif
 #ifdef HAVE_LIBASOUND
 extern DataSrc datasrc_sc;
 #endif
-#ifdef HAVE_LIBESD
-extern DataSrc datasrc_esd;
-#endif
-#ifdef HAVE_LIBCOMEDI
-extern DataSrc datasrc_comedi;
+#ifdef HAVE_LIBESD 
+extern DataSrc datasrc_esd; // XXX: This will not happen anymore...
 #endif
 
 DataSrc *datasrcs[] = {
 #ifdef HAVE_LIBCOMEDI
     &datasrc_comedi,
 #endif
-#ifdef HAVE_LIBESD
-    &datasrc_esd,
-#endif
 #ifdef HAVE_LIBASOUND
-    &datasrc_sc
+    &datasrc_sc,
+#endif
+#ifdef HAVE_LIBESD 
+    &datasrc_esd
 #endif
 };
 
@@ -52,7 +52,7 @@ Channel ch[CHANNELS];
 /* extra global variable definitions */
 char *progname;                 /* the program's name, autoset via argv[0] */
 char version[] = VERSION;       /* version of the program, from Makefile */
-char error[256];                /* buffer for "one-line" error messages */
+char error[4256];               /* buffer for "one-line" error messages */
 int clip = 0;                   /* whether we're maxed out or not */
 char *filename;                 /* default file name */
 int frames = 0;                 /* # of frames (full or partial) captured */
@@ -135,8 +135,8 @@ void parse_args(int argc, char **argv)
         "A:R:S:T:L:C:M:D:F:P:G:o:I:BVXYZ";
     int c;
 
-    /* If a data source, data source option, or ALSA device name was specified on the command line,
-     * parse them first.
+    /* If a data source, data source option, or ALSA device name was specified on the 
+     * command line, parse them first.
      */
 
     while ((c = getopt(argc, argv, flags)) != EOF) {
@@ -171,7 +171,7 @@ void cleanup(void)
 /* initialize the scope */
 void init_scope(void)
 {
-    /* XXX fix me - get better plot/scroll mode defaults here */
+    /* FIXME - get better plot/scroll mode defaults here */
     scope.plot_mode = DEF_P / 2;
     scope.scroll_mode = DEF_P % 2;
     scope.scale = 1.0 / DEF_S;
@@ -184,6 +184,8 @@ void init_scope(void)
     scope.select = DEF_A - 1;
     scope.verbose = DEF_V;
     scope.min_interval = 50;
+    scope.position_step = 0.1;
+    scope.trigger_step = 1;
 }
 
 /* initialize the signals */
@@ -209,9 +211,9 @@ void init_channels(void)
 /* samples needed to draw a current display of RATE
  *
  * scope.scale gives us the timebase in milliseconds per divisions.  Multiply by 10 to get
- * millseconds per screen, divide by 1000 to get seconds per screen, multiply by rate (in
- * samples/sec) to get samples per screen, and add one so rounding doesn't make us end a capture
- * before the end of the screen.
+ * miliseconds per screen, divide by 1000 to get seconds per screen, multiply by rate (in
+ * samples/sec) to get samples per screen, and add one so rounding doesn't make us end a
+ * capture before the end of the screen.
  *
  * XXX MAXWID is defined (in configure.ac) as: 1024*256=262144
  * On long time basis, this results in a sweep that does not fill the screen.
@@ -470,7 +472,7 @@ int datasrc_next(void)
     int i;
     int limit = sizeof(datasrcs)/sizeof(DataSrc *);
 
-    if (datasrci < 0) return datasrc_first();
+    if (datasrci < 0 || limit == 0) return datasrc_first();
 
     for (i=(datasrci+1)%limit; i != datasrci; i=(i+1)%limit) {
         if (datasrc_open(datasrcs[i])) {
@@ -560,6 +562,7 @@ void handle_key(unsigned char c)
         }
         p->show = 1;                    /* always display newly recalled channel */
         clear();
+        update_text();
         return;
     } else if (c >= '1' && c <= '0' + CHANNELS) {
         scope.select = (c - '1');       /* select channel */
@@ -673,9 +676,9 @@ void handle_key(unsigned char c)
         }
         break;
     case ']':
-        p->pos += 0.1;          /* position up */
-        if (p->pos < -1) {
-            p->pos = -1;
+        p->pos += scope.position_step;          /* position up */
+        if (p->pos < -100) {
+            p->pos = -100;
         }
         if (p->pos * p->pos < 0.0001) {
             p->pos = 0;
@@ -684,9 +687,9 @@ void handle_key(unsigned char c)
         show_data();
         break;
     case '[':
-        p->pos -= 0.1;          /* position down */
-        if (p->pos > 1) {
-            p->pos = 1;
+        p->pos -= scope.position_step;          /* position down */
+        if (p->pos > 100) {
+            p->pos = 100;
         }
         if (p->pos * p->pos < 0.0001) {
             p->pos = 0;
@@ -699,6 +702,7 @@ void handle_key(unsigned char c)
             next_func();
             p->show = 1;
             clear();
+            update_text();
         } else {
             message("Math can not run on Channel 1 or 2");
         }
@@ -708,6 +712,7 @@ void handle_key(unsigned char c)
             prev_func();
             p->show = 1;
             clear();
+            update_text();
         } else {
             message("Math can not run on Channel 1 or 2");
         }
@@ -724,14 +729,18 @@ void handle_key(unsigned char c)
         break;
     case '=':
         if (datasrc && datasrc->set_trigger) {  /* increase trigger */
-            scope.trig += 8;
+            scope.trig += scope.trigger_step;
+	    if (scope.trig > 100)
+		    scope.trig = 100;
             datasrc->set_trigger(scope.trigch, &scope.trig, scope.trige);
             clear();
         }
         break;
     case '-':
         if (datasrc && datasrc->set_trigger) {  /* decrease trigger */
-            scope.trig -= 8;
+            scope.trig -= scope.trigger_step;
+	    if (scope.trig < -100)
+		    scope.trig = -100;
             datasrc->set_trigger(scope.trigch, &scope.trig, scope.trige);
             clear();
         }
