@@ -20,7 +20,7 @@ extern char alsaDevice[];
 /* global program variables */
 extern char *progname;
 extern char version[];
-extern char error[256];
+extern char error[4256];
 extern int quit_key_pressed;
 extern int clip;
 extern char *filename;
@@ -42,6 +42,8 @@ typedef struct Scope {          /* The oscilloscope */
     int cursa;
     int cursb;
     int min_interval;
+    float position_step;	/* 0.1 or 1.0 or 10.0 */
+    int trigger_step;		/* 1 or 10 */
 } Scope;
 extern Scope scope;
 
