@@ -12,9 +12,8 @@
 
 extern GtkWidget *menubar;
 extern GtkWidget *glade_window;
-extern GtkWidget *bitscope_options_dialog;
 extern GtkWidget *comedi_options_dialog;
-extern GtkWidget *alsa_options_dialog;
+// extern GtkWidget *alsa_options_dialog; FIXME: where is it?
 extern GtkWidget *databox;
 
 GtkWidget * lookup_widget(const gchar *widget_name);
@@ -22,4 +21,5 @@ GtkWidget * lookup_widget(const gchar *widget_name);
 
 GtkWidget *create_comedi_dialog (void);
 
-void on_main_window_destroy (GtkObject *object, gpointer user_data);
+void set_fixing_widgets (gboolean on_off);
+
